@@ -787,258 +787,3 @@ static void print_str(char *s, int len)
   }
 }
 
-int main()
-{
-  /*  char buff[] = " &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;";
-
-  char buff1[] = " &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; ";
-  */
-
-  /*    char buff[] = "
- &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;crit=&gt;'red', emerg=&gt;'red', warning=&gt;&quot;red&quot;);";
-
-  char buff1[] = "
- &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; crit=&gt;'red', emerg=&gt;'red', warning=&gt;&quot;red&quot;,
- &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; d=&gt;&quot;blue&quot;, w=&gt;&quot;red&quot;,n=&gt;&quot;green&quot;,
- &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; i=&gt;'pink',e=&gt;'red',a=&gt;'red',
- &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; c=&gt;'red');";
-//0 35 0 0 0 36 0 0 35 95 0 0 35 96 0 0 
-  */
-
-  /*  char buff[] = "// $Revision: 1.7 $";
-  char buff1[] = "// $Revision: 1.7 $"; // 0 17 0 0 0 17 0 0 
-  */
-  /*    char buff[] = "hello work";
-  char buff1[] = "h  xello
-  world";//1 6 0 0 4 11 0 1 
-*/
-  /*   char buff[5000] = "     int node_idx = find_node(t, ap->m_node_id,  
-    
-                              t->m_str[ap->m_begin_idx]);  
-";
-  char buff1[5000] = "     int node_idx = find_node(t, ap->m_node_id, ap_begin_char(t, ap));
-  "; //0 85 0 2 0 48 0 0 99 106 2 2 50 57 0 0 
-*/
-
-  /*    char buff[5000] = "   xxx timeAttr = requestCopy.getAttribute(ATXL_MODIFYTIMESTAMP_ATTR);
-   if (!timeAttr) { cvcbcv
-     timeAttr = new atxl_Attribute(ATXL_MODIFYTIMESTAMP_ATTR);
-     requestCopy.addAttribute(timeAttr);
-   } else {
-     timeAttr->values().pingclear();
-";
-  char buff1[5000] = "     timeAttr = requestCopy.getAttribute(ATXL_MODIFYxyzTIMESTAMP_ATTR);
-     if (!timeApptsttr) {
-       timeAttr = new atxl_abcdefAttribute(ATXL_MODIFYTIMESTAMP_ATTR);
-       requestCopy.addAttribute(timeAttr);
-     } else {
-       timeAttr->values().posqgsfclear();
-     }
-     timeAttr->addValue(timeStampStr);
-   }
-   {
-     atxl_Attribute *uuidAttr =
-       requestCopy.getAttribute(ATXL_UUID_ATTR);
-     if (!uuidAttr) {
-       uuidAttr = new atxl_Attribute(ATXL_UUID_ATTR);
-       requestCopy.addAttribute(uuidAttr);
-     } else {
-       uuidAttr->values().clear();
-     }
-     uuidAttr->addValue(atxl_Uuid::get());
-   }
-   {
-     atxl_Attribute *namingAttr =
-       requestCopy.getAttribute(ATXL_NAMINGATTRIBUTE_ATTR);
-     if (!namingAttr) {
-       namingAttr = new atxl_Attribute(ATXL_NAMINGATTRIBUTE_ATTR);
-       requestCopy.addAttribute(namingAttr);
-     } else {
-       namingAttr->values().clear();
-     }
-     namingAttr->addValue(objName);
-     ";// 6 54 0 0 0 52 0 0 54 84 0 1 55 87 0 1 84 91 1 1 91 105 1 2 97 123 1 2 97 125 1 2 123 239 2 5 131 253 2 5 242 251 5 6 259 273 5 6 
-*/
-  //    char buff[5000] = "   timeAttr->addValue(timeStampStr);";
-    /*     string timeStampStr = currentTimeStamp();
-   // add create time stamp attribute
-   atxl_Attribute *timeAttr =
-     requestCopy.getAttribute(ATXL_CREATETIMESTAMP_ATTR);
-   if (!timeAttr) {
-     timeAttr = new atxl_Attribute(ATXL_CREATETIMESTAMP_ATTR);
-     requestCopy.addAttribute(timeAttr);
-   } else {
-     timeAttr->values().clear();
-   }
-   timeAttr->addValue(timeStampStr);
-   ";*/
-    /*  char buff1[5000] = "   {
-     string timeStampStr = currentTimeStamp();
-     // add create time stamp attribute
-     atxl_Attribute *timeAttr =
-       requestCopy.getAttribute(ATXL_CREATETIMESTAMP_ATTR);
-     if (!timeAttr) {
-       timeAttr = new atxl_Attribute(ATXL_CREATETIMESTAMP_ATTR);
-       requestCopy.addAttribute(timeAttr);
-     } else {
-       timeAttr->values().clear();
-     }
-     timeAttr->addValue(timeStampStr);";*/
-    /*      char buff[5000] = "missixissipix";
-    char buff1[5000] = "mxissisxsip";
-        char buff[5000] = "missixxixssip";
-    char buff1[5000] = "xmxissisxsip";
-    */
-    /*    char buff[5000] = "mipssixissip";
-    char buff1[5000] = "xmxissisxsip";
-    */
-    /*    char buff[5000] = "mipssixissip";
-    char buff1[5000] = "xmxissisxsip";
-    */
-  //  int c;
-  //  int i = 0;
-  //  Suffix_Tree t;
-
-  //  while ((c = getchar()) >= 0) { 
-  //    buff[i++] = c; 
-  //  } 
-  //  buff[i] = 0; 
-  //  suffix_tree_init(&t, buff);
-  //  print(&t);
-  //
-  //  char buff[5000] = "xaaab         attrName == ATXL_NAMINGATTRIBUTE_ATTR";
-  //
-  //  char buff1[5000] = "         attrName == ATXL_CREATETIMESTAMP_ATTR ||
-  //     attrName == ATXL_NAMINGATTRIBUTE_ATTR) {";
-  {
-    char buff[5000] = "for comp in *; do
-    if [ -d $comp -a $comp != \"build\" ]; then
-        cd $comp
-";
-    char buff1[5000] = "
-# Build the controller bean
-cd controller
-";
-    char *ret = ediff(buff, buff1);
-    printf("%s\n", ret);
-    /*int *line_attrs1, *line_attrs2, ix;
-    char *ostr1, *ostr2;
-    //    int pos1, pos2, len = 0;
-    equal_segment *equals = NULL, *tmp_seg;
-
-    normalize(&ostr1, &line_attrs1, buff, strlen(buff));
-    normalize(&ostr2, &line_attrs2, buff1, strlen(buff1));
-
-    diff(&equals, ostr1, ostr1, strlen(ostr1), ostr2, ostr2, strlen(ostr2));
-    tmp_seg = equals;
-    while (tmp_seg) {
-      printf("diff: %d %d %d %d\n", tmp_seg->m_begin1, tmp_seg->m_end1,
-             tmp_seg->m_begin2, tmp_seg->m_end2);
-      print_str(ostr1+tmp_seg->m_begin1, tmp_seg->m_end1 - tmp_seg->m_begin1);
-      printf("\n");
-      tmp_seg = tmp_seg->m_next;
-    }
-
-    printf("----------------------------------\n");
-    adjust(equals, buff, buff1);*/
-    /*   lcs(&pos1, &pos2, &len, ostr1, strlen(ostr1), ostr2, strlen(ostr2));
-     */
-    /*    tmp_seg = equals;
-    while (tmp_seg) {
-      printf("diff: %d %d %d %d\n", tmp_seg->m_begin1, tmp_seg->m_end1,
-             tmp_seg->m_begin2, tmp_seg->m_end2);
-      print_str(buff+tmp_seg->m_begin1, tmp_seg->m_end1 - tmp_seg->m_begin1);
-      printf("\n");
-      print_str(buff1+tmp_seg->m_begin2, tmp_seg->m_end2 - tmp_seg->m_begin2);
-      printf("\n");
-      printf("\n");
-      tmp_seg = tmp_seg->m_next;
-    }*/
-    /*    printf("lcs: len=%d pos1=%d pos2=%d\n", len, pos1, pos2);
-    print_str(ostr1+pos1 - len, len);
-    printf("\n");
-    print_str(ostr2+pos2 - strlen(ostr1) - 1 - len, len);*/
-    /*    printf("%s\n %d\n", ostr1, line_attrs1[0]);
-    for (ix = 0; ix < line_attrs1[0]; ix++) {
-      printf("%d\n", line_attrs1[ix+1]);
-      }*/
-  }
-  /*  {
-    int pos1, pos2, len = 0;
-    lcs(&pos1, &pos2, &len, buff, strlen(buff), buff1, strlen(buff1));
-    printf("lcs: len=%d pos1=%d pos2=%d\n", len, pos1 - len, pos2 - strlen(buff) - 1 - len);
-    print_str(buff+pos1 - len, len);
-    printf("\n");
-    print_str(buff1+pos2 - strlen(buff) - 1 - len, len);
-    }*/
-  return 0;
-}
-
-/*
-   string timeStampStr = currentTimeStamp();
-   // add create time stamp attribute
-   atxl_Attribute *timeAttr =
-     requestCopy.getAttribute(ATXL_CREATETIMESTAMP_ATTR);
-   if (!timeAttr) {
-     timeAttr = new atxl_Attribute(ATXL_CREATETIMESTAMP_ATTR);
-     requestCopy.addAttribute(timeAttr);
-   } else {
-     timeAttr->values().clear();
-   }
-   timeAttr->addValue(timeStampStr);
----
-   {
-     string timeStampStr = currentTimeStamp();
-     // add create time stamp attribute
-
-     atxl_Attribute *timeAttr =
-       requestCopy.getAttribute(ATXL_CREATETIMESTAMP_ATTR);
-     if (!timeAttr) {
-       timeAttr = new atxl_Attribute(ATXL_CREATETIMESTAMP_ATTR);
-       requestCopy.addAttribute(timeAttr);
-     } else {
-       timeAttr->values().clear();
-     }
-     timeAttr->addValue(timeStampStr);
-1233,1238c1239,1268
-   timeAttr = requestCopy.getAttribute(ATXL_MODIFYTIMESTAMP_ATTR);
-   if (!timeAttr) {
-     timeAttr = new atxl_Attribute(ATXL_MODIFYTIMESTAMP_ATTR);
-     requestCopy.addAttribute(timeAttr);
-   } else {
-     timeAttr->values().clear();
----
-     timeAttr = requestCopy.getAttribute(ATXL_MODIFYTIMESTAMP_ATTR);
-     if (!timeAttr) {
-       timeAttr = new atxl_Attribute(ATXL_MODIFYTIMESTAMP_ATTR);
-       requestCopy.addAttribute(timeAttr);
-     } else {
-       timeAttr->values().clear();
-     }
-     timeAttr->addValue(timeStampStr);
-   }
-   {
-     atxl_Attribute *uuidAttr =
-       requestCopy.getAttribute(ATXL_UUID_ATTR);
-     if (!uuidAttr) {
-       uuidAttr = new atxl_Attribute(ATXL_UUID_ATTR);
-       requestCopy.addAttribute(uuidAttr);
-     } else {
-       uuidAttr->values().clear();
-     }
-     uuidAttr->addValue(atxl_Uuid::get());
-   }
-   {
-     atxl_Attribute *namingAttr =
-       requestCopy.getAttribute(ATXL_NAMINGATTRIBUTE_ATTR);
-     if (!namingAttr) {
-       namingAttr = new atxl_Attribute(ATXL_NAMINGATTRIBUTE_ATTR);
-       requestCopy.addAttribute(namingAttr);
-     } else {
-       namingAttr->values().clear();
-     }
-     namingAttr->addValue(objName);
-1240d1269
-<   timeAttr->addValue(timeStampStr);
-
-*/
